#!/usr/bin/perl -w

use Image::Magick;

if (scalar(@ARGV) != 1) {
	die("Usage: $0 <file>\n");
}
$filename = $ARGV[0];
die "File '$filename' not found\n" unless (-f $filename);
die "File doesn't have a .png extension\n" unless ($filename =~ /\.png$/);
$image = Image::Magick->new;
$image->Read($filename);
$width = $image->Get('width');
$height = $image->Get('height');
($outfile = $filename) =~ s/\.png$/.asm/;
($outfileinv = $filename) =~ s/\.png$/-inv.asm/;
print "Image size: $width x $height pixels.\n";
die "Image size must be 7 x 41 pixels!\n" if (($width != 7) or ($height != 41));

@PIXELS = $image->GetPixels(map=>'I', width=>$width, height=>$height, normalize=>1);
open ASM, ">$outfile";
print ASM ".db 0xFF, 0xFF, 0xFF, 0xFF, 0xFF";
open ASMINV, ">$outfileinv";
print ASMINV ".db 0x00, 0x00, 0x00, 0x00, 0x00";

for ($y = 0; $y < 41; $y+=6) {
	if ($y % 12 == 6) {
		print ASM ".db ";
		print ASMINV ".db ";
	} else {
		print ASM ", ";
		print ASMINV ", ";
	}
	for ($suby = 0; $suby < 6; $suby++) {
		next if ($suby % 6 == 5);
		$byte = 0;
		$byte |= 0x01 if ($PIXELS[($y+$suby)*7 + 0] < .5);
		$byte |= 0x02 if ($PIXELS[($y+$suby)*7 + 1] < .5);
		$byte |= 0x10 if ($PIXELS[($y+$suby)*7 + 2] < .5);
		$byte |= 0x20 if ($PIXELS[($y+$suby)*7 + 4] < .5);
		$byte |= 0x40 if ($PIXELS[($y+$suby)*7 + 5] < .5);
		$byte |= 0x80 if ($PIXELS[($y+$suby)*7 + 6] < .5);
		if ($suby > 0) {
			print ASM ", ";
			print ASMINV ", ";
		}
		printf ASM "0x%02x", (~$byte) & 0xFF;
		printf ASMINV "0x%02x", $byte;
	}
	if ($y % 12 == 0) {
		print ASM "\n";
		print ASMINV "\n";
	}
}

close ASM;
